@@ -40,7 +40,7 @@
 #include <gtk/gtkinvisible.h>
 #include <gtk/gtksignal.h>
 #include <gdk/gdkkeysyms.h>
-#include <libgnomeui/gnome-canvas.h>
+#include <libgnomecanvas/gnome-canvas.h>
 
 #include "e-tree-table-adapter.h"
 #include "e-tree-model.h"
@@ -434,7 +434,7 @@ ect_max_width (ECellView *ecell_view, int model_col, int view_col)
 	number_of_rows = e_table_model_row_count (ecell_view->e_table_model);
 
 	if (!per_row)
-		subcell_max_width = e_cell_max_width (tree_view->subcell_view, model_col, view_col);
+	subcell_max_width = e_cell_max_width (tree_view->subcell_view, model_col, view_col);
 	
 	for (row = 0; row < number_of_rows; row++) {
 		ETreeModel *tree_model = e_cell_tree_get_tree_model(ecell_view->e_table_model, row);
@@ -512,7 +512,7 @@ ect_show_tooltip (ECellView *ecell_view, int model_col, int view_col, int row,
 	tooltip->x += offset;
 	e_cell_show_tooltip (tree_view->subcell_view, model_col, view_col, row, col_width - offset, tooltip);
 }
-
+		
 /*
  * ECellView::get_bg_color method
  */
@@ -667,8 +667,13 @@ ect_destroy (GtkObject *object)
 		gtk_object_unref (GTK_OBJECT (ect->subcell));
 	ect->subcell = NULL;
 
-	gdk_pixbuf_unref (ect->open_pixbuf);
-	gdk_pixbuf_unref (ect->closed_pixbuf);
+	if (ect->open_pixbuf)
+		gdk_pixbuf_unref (ect->open_pixbuf);
+	ect->open_pixbuf = NULL;
+
+	if (ect->closed_pixbuf)
+		gdk_pixbuf_unref (ect->closed_pixbuf);
+	ect->closed_pixbuf = NULL;
 
 	GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
@@ -680,25 +685,25 @@ e_cell_tree_class_init (GtkObjectClass *object_class)
 
 	object_class->destroy = ect_destroy;
 
-	ecc->new_view         = ect_new_view;
-	ecc->kill_view        = ect_kill_view;
-	ecc->realize          = ect_realize;
-	ecc->unrealize        = ect_unrealize;
-	ecc->draw             = ect_draw;
-	ecc->event            = ect_event;
-	ecc->height           = ect_height;
-	ecc->enter_edit       = ect_enter_edit;
-	ecc->leave_edit       = ect_leave_edit;
-	ecc->print            = ect_print;
-	ecc->print_height     = ect_print_height;
-	ecc->max_width        = ect_max_width;
-	ecc->show_tooltip     = ect_show_tooltip;
+	ecc->new_view   = ect_new_view;
+	ecc->kill_view  = ect_kill_view;
+	ecc->realize    = ect_realize;
+	ecc->unrealize  = ect_unrealize;
+	ecc->draw       = ect_draw;
+	ecc->event      = ect_event;
+	ecc->height     = ect_height;
+	ecc->enter_edit = ect_enter_edit;
+	ecc->leave_edit = ect_leave_edit;
+	ecc->print      = ect_print;
+	ecc->print_height = ect_print_height;
+	ecc->max_width = ect_max_width;
+	ecc->show_tooltip = ect_show_tooltip;
 	ecc->get_bg_color     = ect_get_bg_color;
 
 	parent_class = gtk_type_class (PARENT_TYPE);
 }
 
-E_MAKE_TYPE(e_cell_tree, "ECellTree", ECellTree, e_cell_tree_class_init, NULL, PARENT_TYPE)
+E_MAKE_TYPE(e_cell_tree, "ECellTree", ECellTree, e_cell_tree_class_init, NULL, PARENT_TYPE);
 
 /**
  * e_cell_tree_construct:
