@@ -27,20 +27,18 @@
 
 #include <gdk/gdktypes.h>
 #include <libgnomeprint/gnome-print.h>
+#include <libgnomeprint/gnome-font.h>
 #include <gal/e-table/e-table-model.h>
 #include <gal/e-table/e-table-tooltip.h>
-#include <libgnome/gnome-defs.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
-#define E_CELL_TYPE        (e_cell_get_type ())
-#define E_CELL(o)          (GTK_CHECK_CAST ((o), E_CELL_TYPE, ECell))
-#define E_CELL_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_CELL_TYPE, ECellClass))
-#define E_IS_CELL(o)       (GTK_CHECK_TYPE ((o), E_CELL_TYPE))
-#define E_IS_CELL_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_CELL_TYPE))
-
-typedef gboolean (*ETableSearchFunc) (gconstpointer haystack,
-				      const char *needle);
+#define E_CELL_TYPE         (e_cell_get_type ())
+#define E_CELL(o)           (GTK_CHECK_CAST ((o), E_CELL_TYPE, ECell))
+#define E_CELL_CLASS(k)     (GTK_CHECK_CLASS_CAST((k), E_CELL_TYPE, ECellClass))
+#define E_CELL_GET_CLASS(o) (GTK_CHECK_GET_CLASS((o), E_CELL_TYPE, ECellClass))
+#define E_IS_CELL(o)        (GTK_CHECK_TYPE ((o), E_CELL_TYPE))
+#define E_IS_CELL_CLASS(k)  (GTK_CHECK_CLASS_TYPE ((k), E_CELL_TYPE))
 
 typedef enum {
 	E_CELL_SELECTED       = 1 << 0,
@@ -58,12 +56,12 @@ typedef enum {
 
 	E_CELL_EDITING        = 1 << 4,
 
-	E_CELL_CURSOR         = 1 << 5
+	E_CELL_CURSOR         = 1 << 5,
 } ECellFlags;
 
 typedef enum {
 	E_CELL_GRAB           = 1 << 0,
-	E_CELL_UNGRAB         = 1 << 1
+	E_CELL_UNGRAB         = 1 << 1,
 } ECellActions;
 
 typedef struct {
@@ -84,40 +82,38 @@ typedef struct {
 typedef struct {
 	GtkObjectClass parent_class;
 	
-	ECellView *(*new_view)         (ECell *ecell, ETableModel *table_model, void *e_table_item_view);
-	void       (*kill_view)        (ECellView *ecell_view);
-
-	void       (*realize)          (ECellView *ecell_view);
-	void       (*unrealize)        (ECellView *ecell_view);
-
-	void   	   (*draw)             (ECellView *ecell_view, GdkDrawable *drawable,
-	       			       	int model_col, int view_col, int row,
-				       	ECellFlags flags, int x1, int y1, int x2, int y2);
-	gint   	   (*event)            (ECellView *ecell_view, GdkEvent *event, int model_col, int view_col, int row, ECellFlags flags, ECellActions *actions);
-	void   	   (*focus)            (ECellView *ecell_view, int model_col, int view_col,
-				       	int row, int x1, int y1, int x2, int y2);
-	void   	   (*unfocus)          (ECellView *ecell_view);
-	int        (*height)           (ECellView *ecell_view, int model_col, int view_col, int row);
-
-	void      *(*enter_edit)       (ECellView *ecell_view, int model_col, int view_col, int row);
-	void       (*leave_edit)       (ECellView *ecell_view, int model_col, int view_col, int row, void *context);
+	ECellView *(*new_view)     (ECell *ecell, ETableModel *table_model, void *e_table_item_view);
+	void       (*kill_view)    (ECellView *ecell_view);
+				   
+	void       (*realize)      (ECellView *ecell_view);
+	void       (*unrealize)    (ECellView *ecell_view);
+				   
+	void   	   (*draw)         (ECellView *ecell_view, GdkDrawable *drawable,
+	       			    int model_col, int view_col, int row,
+				    ECellFlags flags, int x1, int y1, int x2, int y2);
+	gint   	   (*event)        (ECellView *ecell_view, GdkEvent *event, int model_col, int view_col, int row, ECellFlags flags, ECellActions *actions);
+	void   	   (*focus)        (ECellView *ecell_view, int model_col, int view_col,
+				    int row, int x1, int y1, int x2, int y2);
+	void   	   (*unfocus)      (ECellView *ecell_view);
+	int        (*height)       (ECellView *ecell_view, int model_col, int view_col, int row);
+				   
+	void      *(*enter_edit)   (ECellView *ecell_view, int model_col, int view_col, int row);
+	void       (*leave_edit)   (ECellView *ecell_view, int model_col, int view_col, int row, void *context);
 	void      *(*save_state)       (ECellView *ecell_view, int model_col, int view_col, int row, void *context);
 	void       (*load_state)       (ECellView *ecell_view, int model_col, int view_col, int row, void *context, void *save_state);
 	void       (*free_state)       (ECellView *ecell_view, int model_col, int view_col, int row, void *save_state);
-	void       (*print)            (ECellView *ecell_view, GnomePrintContext *context,
-				       	int model_col, int view_col, int row,
-				       	gdouble width, gdouble height);
-	gdouble    (*print_height)     (ECellView *ecell_view, GnomePrintContext *context,
-				       	int model_col, int view_col, int row, gdouble width);
-	int        (*max_width)        (ECellView *ecell_view, int model_col, int view_col);
+	void       (*print)        (ECellView *ecell_view, GnomePrintContext *context,
+				    int model_col, int view_col, int row,
+				    gdouble width, gdouble height);
+	gdouble    (*print_height) (ECellView *ecell_view, GnomePrintContext *context,
+				    int model_col, int view_col, int row, gdouble width);
+	int        (*max_width) (ECellView *ecell_view, int model_col, int view_col);
 	int        (*max_width_by_row) (ECellView *ecell_view, int model_col, int view_col, int row);
-	void       (*show_tooltip)     (ECellView *ecell_view, int model_col, int view_col, int row, int col_width, ETableTooltip *tooltip);
+	void       (*show_tooltip) (ECellView *ecell_view, int model_col, int view_col, int row, int col_width, ETableTooltip *tooltip);
 	gchar     *(*get_bg_color)     (ECellView *ecell_view, int row);
-
-	void       (*style_set)        (ECellView *ecell_view, GtkStyle *previous_style);
 } ECellClass;
 
-GtkType    e_cell_get_type                      (void);
+GtkType    e_cell_get_type  (void);
 
 /* View creation methods. */
 ECellView *e_cell_new_view                      (ECell             *ecell,
@@ -133,8 +129,8 @@ gint       e_cell_event                         (ECellView         *ecell_view,
 						 int                row,
 						 ECellFlags         flags,
 						 ECellActions      *actions);
-void       e_cell_realize                       (ECellView         *ecell_view);
-void       e_cell_unrealize                     (ECellView         *ecell_view);
+void       e_cell_realize   (ECellView *ecell_view);
+void       e_cell_unrealize (ECellView *ecell_view);
 void       e_cell_draw                          (ECellView         *ecell_view,
 						 GdkDrawable       *drawable,
 						 int                model_col,
@@ -174,9 +170,6 @@ void       e_cell_show_tooltip                  (ECellView         *ecell_view,
 						 ETableTooltip     *tooltip);
 gchar     *e_cell_get_bg_color                  (ECellView         *ecell_view,
 						 int                row);
-void       e_cell_style_set                     (ECellView         *ecell_view,
-						 GtkStyle          *previous_style);
-
 void       e_cell_focus                         (ECellView         *ecell_view,
 						 int                model_col,
 						 int                view_col,
@@ -185,7 +178,7 @@ void       e_cell_focus                         (ECellView         *ecell_view,
 						 int                y1,
 						 int                x2,
 						 int                y2);
-void       e_cell_unfocus                       (ECellView         *ecell_view);
+void       e_cell_unfocus   (ECellView *ecell_view);
 int        e_cell_height                        (ECellView         *ecell_view,
 						 int                model_col,
 						 int                view_col,
@@ -217,6 +210,6 @@ void       e_cell_free_state                    (ECellView         *ecell_view,
 						 void              *state);
 
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* _E_CELL_H_ */
