@@ -1,4 +1,27 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* 
+ * e-table-header.h
+ * Copyright 1999, 2000, 2001, Ximian, Inc.
+ *
+ * Authors:
+ *   Chris Lahey <clahey@ximian.com>
+ *   Miguel de Icaza <miguel@ximian.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
+ */
+
 #ifndef _E_TABLE_COLUMN_H_
 #define _E_TABLE_COLUMN_H_
 
@@ -7,6 +30,10 @@
 #include <gal/e-table/e-table-sort-info.h>
 #include <gal/e-table/e-table-col.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 typedef struct _ETableHeader ETableHeader;
 
 #define E_TABLE_HEADER_TYPE        (e_table_header_get_type ())
@@ -79,7 +106,13 @@ int           e_table_header_col_diff               (ETableHeader *eth,
 void          e_table_header_calc_widths            (ETableHeader *eth);
 GList        *e_table_header_get_selected_indexes   (ETableHeader *eth);
 
+void          e_table_header_update_horizontal      (ETableHeader *eth);
+int           e_table_header_prioritized_column     (ETableHeader *eth);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #endif /* _E_TABLE_HEADER_H_ */
 
