@@ -21,62 +21,59 @@
  * 02111-1307, USA.
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include "e-table-specification.h"
 
 #include <stdlib.h>
 #include <string.h>
-
+#include <gtk/gtksignal.h>
 #include <libxml/parser.h>
 #include <libxml/xmlmemory.h>
 #include "gal/util/e-util.h"
 #include "gal/util/e-xml-utils.h"
 
-static GObjectClass *etsp_parent_class;
+#define PARENT_TYPE (gtk_object_get_type ())
+
+static GtkObjectClass *etsp_parent_class;
 
 static void
-etsp_finalize (GObject *object)
+etsp_destroy (GtkObject *object)
 {
 	ETableSpecification *etsp = E_TABLE_SPECIFICATION (object);
 	int i;
 
 	if (etsp->columns) {
 		for (i = 0; etsp->columns[i]; i++) {
-			g_object_unref (etsp->columns[i]);
+			gtk_object_unref (GTK_OBJECT (etsp->columns[i]));
 		}
 		g_free (etsp->columns);
 		etsp->columns = NULL;
 	}
 
 	if (etsp->state)
-		g_object_unref (etsp->state);
+		gtk_object_unref (GTK_OBJECT (etsp->state));
 	etsp->state                = NULL;
 
 	g_free (etsp->click_to_add_message);
 	etsp->click_to_add_message = NULL;
 
-	g_free (etsp->domain);
-	etsp->domain		   = NULL;
-
-	etsp_parent_class->finalize (object);
+	GTK_OBJECT_CLASS (etsp_parent_class)->destroy (object);
 }
 
 static void
-etsp_class_init (GObjectClass *klass)
+etsp_class_init (GtkObjectClass *klass)
 {
-	etsp_parent_class = g_type_class_peek_parent (klass);
+	etsp_parent_class = gtk_type_class (PARENT_TYPE);
 	
-	klass->finalize = etsp_finalize;
+	klass->destroy = etsp_destroy;
 }
 
 static void
 etsp_init (ETableSpecification *etsp)
 {
-	etsp->columns                = NULL;
-	etsp->state                  = NULL;
+	etsp->columns               = NULL;
+	etsp->state                 = NULL;
 
 	etsp->alternating_row_colors = TRUE;
 	etsp->no_headers             = FALSE;
@@ -86,17 +83,15 @@ etsp_init (ETableSpecification *etsp)
 	etsp->vertical_draw_grid     = FALSE;
 	etsp->draw_focus             = TRUE;
 	etsp->horizontal_scrolling   = FALSE;
-	etsp->horizontal_resize      = FALSE;
 	etsp->allow_grouping         = TRUE;
 
-	etsp->cursor_mode            = E_CURSOR_SIMPLE;
-	etsp->selection_mode         = GTK_SELECTION_MULTIPLE;
+	etsp->cursor_mode           = E_CURSOR_SIMPLE;
+	etsp->selection_mode        = GTK_SELECTION_MULTIPLE;
 
-	etsp->click_to_add_message   = NULL;
-	etsp->domain                 = NULL;
+	etsp->click_to_add_message  = NULL;
 }
 
-E_MAKE_TYPE (e_table_specification, "ETableSpecification", ETableSpecification, etsp_class_init, etsp_init, G_TYPE_OBJECT)
+E_MAKE_TYPE (e_table_specification, "ETableSpecification", ETableSpecification, etsp_class_init, etsp_init, PARENT_TYPE);
 
 /**
  * e_table_specification_new:
@@ -109,7 +104,7 @@ E_MAKE_TYPE (e_table_specification, "ETableSpecification", ETableSpecification,
 ETableSpecification *
 e_table_specification_new (void)
 {
-	ETableSpecification *etsp = g_object_new (E_TABLE_SPECIFICATION_TYPE, NULL);
+	ETableSpecification *etsp = gtk_type_new (E_TABLE_SPECIFICATION_TYPE);
 
 	return (ETableSpecification *) etsp;
 }
@@ -196,7 +191,6 @@ e_table_specification_load_from_node (ETableSpecification *specification,
 	}
 	specification->draw_focus = e_xml_get_bool_prop_by_name_with_default (node, "draw-focus", TRUE);
 	specification->horizontal_scrolling = e_xml_get_bool_prop_by_name_with_default (node, "horizontal-scrolling", FALSE);
-	specification->horizontal_resize = e_xml_get_bool_prop_by_name_with_default (node, "horizontal-resize", FALSE);
 	specification->allow_grouping = e_xml_get_bool_prop_by_name_with_default (node, "allow-grouping", TRUE);
 
 	specification->selection_mode = GTK_SELECTION_MULTIPLE;
@@ -218,27 +212,18 @@ e_table_specification_load_from_node (ETableSpecification *specification,
 		specification->cursor_mode = E_CURSOR_SPREADSHEET;
 	}
 	g_free (temp);
-
 	g_free (specification->click_to_add_message);
+
 	specification->click_to_add_message =
 		e_xml_get_string_prop_by_name (
 			node, "_click-to-add-message");
 
-	g_free (specification->domain);
-	specification->domain =
-		e_xml_get_string_prop_by_name (
-			node, "gettext-domain");
-	if (specification->domain && !*specification->domain) {
-		g_free (specification->domain);
-		specification->domain = NULL;
-	}
-
 	if (specification->state)
-		g_object_unref (specification->state);
+		gtk_object_unref (GTK_OBJECT (specification->state));
 	specification->state = NULL;
 	if (specification->columns) {
 		for (i = 0; specification->columns[i]; i++) {
-			g_object_unref (specification->columns[i]);
+			gtk_object_unref (GTK_OBJECT (specification->columns[i]));
 		}
 		g_free (specification->columns);
 	}
@@ -257,11 +242,6 @@ e_table_specification_load_from_node (ETableSpecification *specification,
 		}
 	}
 
-	if (specification->state == NULL) {
-		/* Make the default state.  */
-		specification->state = e_table_state_vanilla (g_list_length (list));
-	}
-
 	specification->columns = g_new (ETableColumnSpecification *, g_list_length (list) + 1);
 	for (list2 = list, i = 0; list2; list2 = g_list_next (list2), i++) {
 		specification->columns[i] = list2->data;
@@ -277,29 +257,21 @@ e_table_specification_load_from_node (ETableSpecification *specification,
  *
  * This routine stores the @specification into @filename.  
  *
- * Returns: 0 on success or -1 on error.
+ * Returns: the number of bytes written or -1 on error.
  */
 int
 e_table_specification_save_to_file (ETableSpecification *specification,
 				    const char          *filename)
 {
 	xmlDoc *doc;
-	int ret;
-	
+
 	g_return_val_if_fail (specification != NULL, -1);
 	g_return_val_if_fail (filename != NULL, -1);
 	g_return_val_if_fail (E_IS_TABLE_SPECIFICATION (specification), -1);
 	
-	if ((doc = xmlNewDoc ("1.0")) == NULL)
-		return -1;
-	
+	doc = xmlNewDoc ("1.0");
 	xmlDocSetRootElement (doc, e_table_specification_save_to_node (specification, doc));
-	
-	ret = e_xml_save_file (filename, doc);
-	
-	xmlFreeDoc (doc);
-	
-	return ret;
+	return xmlSaveFile (filename, doc);
 }
 
 /**
@@ -363,7 +335,6 @@ e_table_specification_save_to_node (ETableSpecification *specification,
 	e_xml_set_bool_prop_by_name (node, "vertical-draw-grid", specification->vertical_draw_grid);
 	e_xml_set_bool_prop_by_name (node, "draw-focus", specification->draw_focus);
 	e_xml_set_bool_prop_by_name (node, "horizontal-scrolling", specification->horizontal_scrolling);
-	e_xml_set_bool_prop_by_name (node, "horizontal-resize", specification->horizontal_resize);
 	e_xml_set_bool_prop_by_name (node, "allow-grouping", specification->allow_grouping);
 
 	switch (specification->selection_mode){
@@ -385,7 +356,6 @@ e_table_specification_save_to_node (ETableSpecification *specification,
 	xmlSetProp (node, "cursor-mode", s);
 
 	xmlSetProp (node, "_click-to-add-message", specification->click_to_add_message);
-	xmlSetProp (node, "gettext-domain", specification->domain);
 
 	if (specification->columns){
 		int i;
