@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * gal-view-collection.c
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -26,10 +26,8 @@
 #include <util/e-i18n.h>
 #include <ctype.h>
 #include <string.h>
-#include <errno.h>
 #include <gtk/gtksignal.h>
-#include <gnome-xml/parser.h>
-#include <libgnome/gnome-defs.h>
+#include <libxml/parser.h>
 #include <libgnome/gnome-util.h>
 #include <gal/util/e-util.h>
 #include <gal/util/e-xml-utils.h>
@@ -42,8 +40,6 @@
 
 static GtkObjectClass *gal_view_collection_parent_class;
 
-#define d(x) x
-
 enum {
 	DISPLAY_VIEW,
 	CHANGED,
@@ -86,12 +82,8 @@ static void
 gal_view_collection_item_free (GalViewCollectionItem *item)
 {
 	g_free(item->id);
-	if (item->view) {
-		if (item->view_changed_id)
-			gtk_signal_disconnect (GTK_OBJECT (item->view),
-					       item->view_changed_id);
+	if (item->view)
 		gtk_object_unref(GTK_OBJECT(item->view));
-	}
 	g_free(item);
 }
 
@@ -159,31 +151,26 @@ gal_view_collection_destroy (GtkObject *object)
 	for (i = 0; i < collection->view_count; i++) {
 		gal_view_collection_item_free (collection->view_data[i]);
 	}
-	g_free(collection->view_data);
+	g_free (collection->view_data);
+	collection->view_data  = NULL;
 	collection->view_count = 0;
-	collection->view_data = NULL;
 
-	e_free_object_list(collection->factory_list);
+	e_free_object_list (collection->factory_list);
 	collection->factory_list = NULL;
 
 	for (i = 0; i < collection->removed_view_count; i++) {
 		gal_view_collection_item_free (collection->removed_view_data[i]);
 	}
 	g_free(collection->removed_view_data);
+	collection->removed_view_data  = NULL;
 	collection->removed_view_count = 0;
-	collection->removed_view_data = NULL;
 
 	g_free(collection->system_dir);
-	g_free(collection->local_dir);
 	collection->system_dir = NULL;
+
+	g_free(collection->local_dir);
 	collection->local_dir = NULL;
 
-	g_free (collection->default_view);
-	collection->default_view = NULL;
-
-	g_free (collection->title);
-	collection->title = NULL;
-
 	if (gal_view_collection_parent_class->destroy)
 		(*gal_view_collection_parent_class->destroy)(object);
 }
@@ -201,7 +188,7 @@ gal_view_collection_class_init (GtkObjectClass *object_class)
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GalViewCollectionClass, display_view),
-				gtk_marshal_NONE__OBJECT,
+				e_marshal_NONE__OBJECT,
 				GTK_TYPE_NONE, 1, GAL_VIEW_TYPE);
 
 	gal_view_collection_signals [CHANGED] =
@@ -221,28 +208,24 @@ gal_view_collection_class_init (GtkObjectClass *object_class)
 static void
 gal_view_collection_init (GalViewCollection *collection)
 {
-	collection->view_data             = NULL;
-	collection->view_count            = 0;
-	collection->factory_list          = NULL;
+	collection->view_data          = NULL;
+	collection->view_count         = 0;
+	collection->factory_list       = NULL;
 
-	collection->removed_view_data     = NULL;
-	collection->removed_view_count    = 0;
+	collection->removed_view_data  = NULL;
+	collection->removed_view_count = 0;
 
-	collection->system_dir            = NULL;
-	collection->local_dir             = NULL;
+	collection->system_dir         = NULL;
+	collection->local_dir          = NULL;
 
-	collection->loaded                = FALSE;
-	collection->default_view          = NULL;
-	collection->default_view_built_in = TRUE;
-
-	collection->title                 = NULL;
+	collection->loaded             = FALSE;
 }
 
 /**
  * gal_view_collection_get_type:
  *
  */
-guint
+GtkType
 gal_view_collection_get_type (void)
 {
 	static guint type = 0;
@@ -278,14 +261,6 @@ gal_view_collection_new                      (void)
 	return gtk_type_new(gal_view_collection_get_type());
 }
 
-void
-gal_view_collection_set_title (GalViewCollection *collection,
-			       const char *title)
-{
-	g_free (collection->title);
-	collection->title = g_strdup (title);
-}
-
 /**
  * gal_view_collection_set_storage_directories
  * @collection: The view collection to initialize
@@ -360,11 +335,14 @@ gal_view_collection_real_load_view_from_file (GalViewCollection *collection, con
 		}
 	}
 	if (factory) {
+		char *fullpath;
 		GalView *view;
 
+		fullpath = g_concat_dir_and_file(dir, filename);
 		view = gal_view_factory_new_view (factory, title);
 		gal_view_set_title (view, title);
-		gal_view_load(view, filename);
+		gal_view_load(view, fullpath);
+		g_free(fullpath);
 		return view;
 	}
 	return NULL;
@@ -392,17 +370,12 @@ load_single_file (GalViewCollection *collection,
 	item->title = e_xml_get_translated_utf8_string_prop_by_name(node, "title");
 	item->type = e_xml_get_string_prop_by_name(node, "type");
 	item->collection = collection;
-	item->view_changed_id = 0;
 
 	if (item->filename) {
-		char *fullpath;
-		fullpath = g_concat_dir_and_file(dir, item->filename);
-		item->view = gal_view_collection_real_load_view_from_file (collection, item->type, item->title, dir, fullpath);
-		g_free(fullpath);
+		item->view = gal_view_collection_real_load_view_from_file (collection, item->type, item->title, dir, item->filename);
 		if (item->view) {
-			item->view_changed_id =
-				gtk_signal_connect(GTK_OBJECT(item->view), "changed",
-						   GTK_SIGNAL_FUNC(view_changed), item);
+			gtk_signal_connect(GTK_OBJECT(item->view), "changed",
+					   GTK_SIGNAL_FUNC(view_changed), item);
 		}
 	}
 	return item;
@@ -417,7 +390,6 @@ load_single_dir (GalViewCollection *collection,
 	xmlNode *root;
 	xmlNode *child;
 	char *filename = g_concat_dir_and_file(dir, "galview.xml");
-	char *default_view;
 
 	doc = xmlParseFile(filename);
 	if (!doc) {
@@ -464,16 +436,6 @@ load_single_dir (GalViewCollection *collection,
 		g_free(id);
 	}
 
-	default_view = e_xml_get_string_prop_by_name (root, "default-view");
-	if (default_view) {
-		if (local)
-			collection->default_view_built_in = FALSE;
-		else
-			collection->default_view_built_in = TRUE;
-		g_free (collection->default_view);
-		collection->default_view = default_view;
-	}
-
 	g_free(filename);
 	xmlFreeDoc(doc);
 }
@@ -495,9 +457,6 @@ gal_view_collection_load              (GalViewCollection *collection)
 	g_return_if_fail (collection->system_dir != NULL);
 	g_return_if_fail (!collection->loaded);
 
-	if ((e_create_directory(collection->local_dir) == -1) && errno != EEXIST)
-		g_warning ("Unable to create dir %s: %s", collection->local_dir, g_strerror(errno));
-
 	load_single_dir(collection, collection->local_dir, TRUE);
 	load_single_dir(collection, collection->system_dir, FALSE);
 	gal_view_collection_changed(collection);
@@ -525,14 +484,12 @@ gal_view_collection_save              (GalViewCollection *collection)
 	g_return_if_fail (GAL_IS_VIEW_COLLECTION (collection));
 	g_return_if_fail (collection->local_dir != NULL);
 
+	e_create_directory(collection->local_dir);
+
 	doc = xmlNewDoc("1.0");
 	root = xmlNewNode(NULL, "GalViewCollection");
 	xmlDocSetRootElement(doc, root);
 
-	if (collection->default_view && !collection->default_view_built_in) {
-		e_xml_set_string_prop_by_name(root, "default-view", collection->default_view);
-	}
-
 	for (i = 0; i < collection->view_count; i++) {
 		xmlNode *child;
 		GalViewCollectionItem *item;
@@ -564,8 +521,7 @@ gal_view_collection_save              (GalViewCollection *collection)
 		e_xml_set_string_prop_by_name(child, "type", item->type);
 	}
 	filename = g_concat_dir_and_file(collection->local_dir, "galview.xml");
-	if (e_xml_save_file(filename, doc) == -1)
-		g_warning ("Unable to save view to %s - %s", filename, g_strerror (errno));
+	xmlSaveFile(filename, doc);
 	xmlFreeDoc(doc);
 	g_free(filename);
 }
@@ -634,7 +590,7 @@ gal_view_collection_get_view_index_by_id     (GalViewCollection *collection, con
 			return i;
 	}
 	return -1;
-}
+	}
 
 char *
 gal_view_collection_get_view_id_by_index (GalViewCollection *collection, int n)
@@ -671,9 +627,8 @@ gal_view_collection_append                   (GalViewCollection *collection,
 	item->collection = collection;
 	gtk_object_ref(GTK_OBJECT(view));
 
-	item->view_changed_id =
-		gtk_signal_connect(GTK_OBJECT(item->view), "changed",
-				   GTK_SIGNAL_FUNC(view_changed), item);
+	gtk_signal_connect(GTK_OBJECT(item->view), "changed",
+			   GTK_SIGNAL_FUNC(view_changed), item);
 
 	collection->view_data = g_renew(GalViewCollectionItem *, collection->view_data, collection->view_count + 1);
 	collection->view_data[collection->view_count] = item;
@@ -694,7 +649,6 @@ gal_view_collection_delete_view              (GalViewCollection *collection,
 
 	item = collection->view_data[i];
 	memmove(collection->view_data + i, collection->view_data + i + 1, (collection->view_count - i - 1) * sizeof(GalViewCollectionItem *));
-	collection->view_count --;
 	if (item->built_in) {
 		g_free(item->filename);
 		item->filename = NULL;
@@ -733,9 +687,8 @@ gal_view_collection_copy_view                (GalViewCollection *collection,
 	item->view = gal_view_clone(view);
 	item->collection = collection;
 
-	item->view_changed_id =
-		gtk_signal_connect(GTK_OBJECT(item->view), "changed",
-				   GTK_SIGNAL_FUNC(view_changed), item);
+	gtk_signal_connect(GTK_OBJECT(item->view), "changed",
+			   GTK_SIGNAL_FUNC(view_changed), item);
 
 	collection->view_data = g_renew(GalViewCollectionItem *, collection->view_data, collection->view_count + 1);
 	collection->view_data[collection->view_count] = item;
@@ -749,93 +702,3 @@ gal_view_collection_loaded (GalViewCollection *collection)
 {
 	return collection->loaded;
 }
-
-const char *
-gal_view_collection_append_with_title (GalViewCollection *collection, const char *title, GalView *view)
-{
-	GalViewCollectionItem *item;
-
-	g_return_val_if_fail (collection != NULL, NULL);
-	g_return_val_if_fail (GAL_IS_VIEW_COLLECTION (collection), NULL);
-	g_return_val_if_fail (view != NULL, NULL);
-	g_return_val_if_fail (GAL_IS_VIEW (view), NULL);
-
-	gal_view_set_title (view, title);
-
-	d(g_print("%s: %p\n", __FUNCTION__, view));
-
-	item = g_new(GalViewCollectionItem, 1);
-	item->ever_changed = TRUE;
-	item->changed = TRUE;
-	item->built_in = FALSE;
-	item->title = g_strdup(gal_view_get_title(view));
-	item->type = g_strdup(gal_view_get_type_code(view));
-	item->id = gal_view_generate_id(collection, view);
-	item->filename = g_strdup_printf("%s.galview", item->id);
-	item->view = view;
-	item->collection = collection;
-	gtk_object_ref(GTK_OBJECT(view));
-
-	item->view_changed_id =
-		gtk_signal_connect(GTK_OBJECT(item->view), "changed",
-				   GTK_SIGNAL_FUNC(view_changed), item);
-
-	collection->view_data = g_renew(GalViewCollectionItem *, collection->view_data, collection->view_count + 1);
-	collection->view_data[collection->view_count] = item;
-	collection->view_count ++;
-
-	gal_view_collection_changed(collection);
-	return item->id;
-}
-
-const char *
-gal_view_collection_set_nth_view (GalViewCollection *collection, int i, GalView *view)
-{
-	GalViewCollectionItem *item;
-
-	g_return_val_if_fail (collection != NULL, NULL);
-	g_return_val_if_fail (GAL_IS_VIEW_COLLECTION (collection), NULL);
-	g_return_val_if_fail (view != NULL, NULL);
-	g_return_val_if_fail (GAL_IS_VIEW (view), NULL);
-	g_return_val_if_fail (i >= 0, NULL);
-	g_return_val_if_fail (i < collection->view_count, NULL);
-
-	d(g_print("%s: %p\n", __FUNCTION__, view));
-
-	item = collection->view_data[i];
-
-	gal_view_set_title (view, item->title);
-	gtk_object_ref (GTK_OBJECT (view));
-	if (item->view) {
-		gtk_signal_disconnect (GTK_OBJECT (item->view),
-				       item->view_changed_id);
-		gtk_object_unref (GTK_OBJECT (item->view));
-	}
-	item->view = view;
-
-	item->ever_changed = TRUE;
-	item->changed = TRUE;
-	item->type = g_strdup(gal_view_get_type_code(view));
-
-	item->view_changed_id =
-		gtk_signal_connect(GTK_OBJECT(item->view), "changed",
-				   GTK_SIGNAL_FUNC(view_changed), item);
-
-	gal_view_collection_changed (collection);
-	return item->id;
-}
-
-const char *
-gal_view_collection_get_default_view (GalViewCollection *collection)
-{
-	return collection->default_view;
-}
-
-void
-gal_view_collection_set_default_view (GalViewCollection *collection, const char *id)
-{
-	g_free (collection->default_view);
-	collection->default_view = g_strdup (id);
-	gal_view_collection_changed (collection);
-	collection->default_view_built_in = FALSE;
-}
