@@ -58,8 +58,6 @@ static void e_group_bar_size_allocate (GtkWidget *widget,
 				       GtkAllocation *allocation);
 static gint e_group_bar_expose (GtkWidget      *widget,
 				GdkEventExpose *event);
-static void e_group_bar_draw (GtkWidget    *widget,
-			      GdkRectangle *area);
 static void e_group_bar_add (GtkContainer *container,
 			     GtkWidget    *widget);
 static void e_group_bar_remove (GtkContainer     *container,
@@ -156,7 +154,6 @@ e_group_bar_class_init (EGroupBarClass *class)
 	widget_class->size_request	= e_group_bar_size_request;
  	widget_class->size_allocate	= e_group_bar_size_allocate;
 	widget_class->expose_event	= e_group_bar_expose;
-	widget_class->draw		= e_group_bar_draw;
 
 	container_class->add		= e_group_bar_add;
 	container_class->remove		= e_group_bar_remove;
@@ -215,7 +212,9 @@ e_group_bar_destroy (GtkObject *object)
 	   destroy our children array until after. */
 	GTK_OBJECT_CLASS (parent_class)->destroy (object);
 
-	g_array_free (group_bar->children, TRUE);
+	if (group_bar->children)
+	    g_array_free (group_bar->children, TRUE);
+	group_bar->children = NULL;
 }
 
 
@@ -581,7 +580,7 @@ e_group_bar_expose (GtkWidget      *widget,
 	return FALSE;
 }
 
-
+#if 0
 static void
 e_group_bar_draw (GtkWidget    *widget,
 		  GdkRectangle *area)
@@ -613,7 +612,7 @@ e_group_bar_draw (GtkWidget    *widget,
 		}
 	}
 }
-
+#endif
 
 static void
 e_group_bar_add (GtkContainer *container,
@@ -989,19 +988,13 @@ e_group_bar_add_group		(EGroupBar	*group_bar,
 			    GTK_SIGNAL_FUNC (e_group_bar_on_button_clicked),
 			    group_bar);
 
+	gtk_signal_connect (GTK_OBJECT (group->button), "drag_motion",
+			    GTK_SIGNAL_FUNC (e_group_bar_on_button_drag_motion),
+			    group_bar);
 	gtk_signal_connect (GTK_OBJECT (group->button), "drag_leave",
 			    GTK_SIGNAL_FUNC (e_group_bar_on_button_drag_leave),
 			    group_bar);
 
-	/* Set up the button as a drop target.  */
-
-	gtk_drag_dest_set (GTK_WIDGET (group->button),
-			   0, NULL, 0,
-			   GDK_ACTION_COPY | GDK_ACTION_MOVE);
-
-	gtk_signal_connect (GTK_OBJECT (group->button), "drag_motion",
-			    GTK_SIGNAL_FUNC (e_group_bar_on_button_drag_motion),
-			    group_bar);
 	return group_num;
 }
 
@@ -1495,8 +1488,7 @@ e_group_bar_on_button_drag_motion (GtkWidget	      *widget,
 			group_bar->auto_show_group_num = group_num;
 		}
 	}
-
-	return FALSE;
+	return TRUE;
 }
 
 
