@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-canvas.c
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -24,12 +24,9 @@
 #include <gtk/gtksignal.h>
 #include "e-canvas.h"
 #include "gal/util/e-util.h"
-#include <X11/Xlib.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkimmulticontext.h>
 
 static void e_canvas_init           (ECanvas         *card);
-static void e_canvas_dispose        (GObject        *object);
+static void e_canvas_destroy        (GtkObject        *object);
 static void e_canvas_class_init	    (ECanvasClass    *klass);
 static void e_canvas_realize        (GtkWidget        *widget);
 static void e_canvas_unrealize      (GtkWidget        *widget);
@@ -47,16 +44,8 @@ static gint e_canvas_focus_in       (GtkWidget        *widget,
 static gint e_canvas_focus_out      (GtkWidget        *widget,
 				     GdkEventFocus    *event);
 
-static void e_canvas_style_set      (GtkWidget        *widget,
-				     GtkStyle         *previous_style);
-
-static int emit_event (GnomeCanvas *canvas, GdkEvent *event);
-
-#define PARENT_TYPE GNOME_TYPE_CANVAS
 static GnomeCanvasClass *parent_class = NULL;
 
-#define d(x)
-
 enum {
 	REFLOW,
 	LAST_SIGNAL
@@ -64,48 +53,66 @@ enum {
 
 static guint e_canvas_signals [LAST_SIGNAL] = { 0, };
 
-E_MAKE_TYPE (e_canvas,
-	     "ECanvas",
-	     ECanvas,
-	     e_canvas_class_init,
-	     e_canvas_init,
-	     PARENT_TYPE)
+GtkType
+e_canvas_get_type (void)
+{
+	static GtkType canvas_type = 0;
+
+	if (!canvas_type)
+	{
+		static const GtkTypeInfo canvas_info =
+		{
+			"ECanvas",
+			sizeof (ECanvas),
+			sizeof (ECanvasClass),
+			(GtkClassInitFunc) e_canvas_class_init,
+			(GtkObjectInitFunc) e_canvas_init,
+			/* reserved_1 */ NULL,
+			/* reserved_2 */ NULL,
+			(GtkClassInitFunc) NULL,
+		};
+
+		canvas_type = gtk_type_unique (gnome_canvas_get_type (), &canvas_info);
+	}
+
+	return canvas_type;
+}
 
 static void
 e_canvas_class_init (ECanvasClass *klass)
 {
-	GObjectClass *object_class;
+	GtkObjectClass *object_class;
 	GnomeCanvasClass *canvas_class;
 	GtkWidgetClass *widget_class;
 
-	object_class                       = (GObjectClass*) klass;
-	canvas_class                       = (GnomeCanvasClass *) klass;
-	widget_class                       = (GtkWidgetClass *) klass;
+	object_class = (GtkObjectClass*) klass;
+	canvas_class = (GnomeCanvasClass *) klass;
+	widget_class = (GtkWidgetClass *) klass;
 
-	parent_class                       = g_type_class_ref (PARENT_TYPE);
+	parent_class = gtk_type_class (gnome_canvas_get_type ());
 
-	object_class->dispose              = e_canvas_dispose;
+	object_class->destroy = e_canvas_destroy;
 
-	widget_class->key_press_event      = e_canvas_key;
-	widget_class->key_release_event    = e_canvas_key;
-	widget_class->button_press_event   = e_canvas_button;
+	widget_class->key_press_event = e_canvas_key;
+	widget_class->key_release_event = e_canvas_key;
+	widget_class->button_press_event = e_canvas_button;
 	widget_class->button_release_event = e_canvas_button;
-	widget_class->focus_in_event       = e_canvas_focus_in;
-	widget_class->focus_out_event      = e_canvas_focus_out;
-	widget_class->style_set            = e_canvas_style_set;
-	widget_class->realize              = e_canvas_realize;
-	widget_class->unrealize            = e_canvas_unrealize;
+	widget_class->focus_in_event = e_canvas_focus_in;
+	widget_class->focus_out_event = e_canvas_focus_out;
+	widget_class->realize = e_canvas_realize;
+	widget_class->unrealize = e_canvas_unrealize;
 
-	klass->reflow                      = NULL;
+	klass->reflow = NULL;
 
 	e_canvas_signals [REFLOW] =
-		g_signal_new ("reflow",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ECanvasClass, reflow),
-			      NULL, NULL,
-			      e_marshal_NONE__NONE,
-			      G_TYPE_NONE, 0);
+		gtk_signal_new ("reflow",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ECanvasClass, reflow),
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
+
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, e_canvas_signals, LAST_SIGNAL);
 }
 
 static void
@@ -113,12 +120,15 @@ e_canvas_init (ECanvas *canvas)
 {
 	canvas->selection = NULL;
 	canvas->cursor = NULL;
-	canvas->im_context = gtk_im_multicontext_new ();
+#ifdef GAL_GDK_IM
+	canvas->ic = NULL;
+	canvas->ic_attr = NULL;
+#endif
 	canvas->tooltip_window = NULL;
 }
 
 static void
-e_canvas_dispose (GObject *object)
+e_canvas_destroy (GtkObject *object)
 {
 	ECanvas *canvas = E_CANVAS(object);
 
@@ -126,58 +136,57 @@ e_canvas_dispose (GObject *object)
 		g_source_remove(canvas->idle_id);
 	canvas->idle_id = 0;
 
-	if (canvas->grab_cancelled_check_id)
-		g_source_remove (canvas->grab_cancelled_check_id);
-	canvas->grab_cancelled_check_id = 0;
-
 	if (canvas->toplevel) {
 		if (canvas->visibility_notify_id)
-			g_signal_handler_disconnect (canvas->toplevel,
-						     canvas->visibility_notify_id);
+			gtk_signal_disconnect (GTK_OBJECT(canvas->toplevel),
+					       canvas->visibility_notify_id);
 		canvas->visibility_notify_id = 0;
 
-		g_object_unref (canvas->toplevel);
+		gtk_object_unref(GTK_OBJECT(canvas->toplevel));
 		canvas->toplevel = NULL;
 	}
 
 	e_canvas_hide_tooltip(canvas);
 
-	if ((G_OBJECT_CLASS (parent_class))->dispose)
-		(*(G_OBJECT_CLASS (parent_class))->dispose) (object);
+	if ((GTK_OBJECT_CLASS (parent_class))->destroy)
+		(*(GTK_OBJECT_CLASS (parent_class))->destroy) (object);
 }
 
 GtkWidget *
 e_canvas_new ()
 {
-	return GTK_WIDGET (g_object_new (E_CANVAS_TYPE, NULL));
+	return GTK_WIDGET (gtk_type_new (e_canvas_get_type ()));
 }
 
 
+/* Returns whether the item is an inferior of or is equal to the parent. */
+static int
+is_descendant (GnomeCanvasItem *item, GnomeCanvasItem *parent)
+{
+	for (; item; item = item->parent)
+		if (item == parent)
+			return TRUE;
+
+	return FALSE;
+}
+
 /* Emits an event for an item in the canvas, be it the current item, grabbed
  * item, or focused item, as appropriate.
  */
 static int
 emit_event (GnomeCanvas *canvas, GdkEvent *event)
 {
-	GdkEvent *ev;
+	GdkEvent ev;
 	gint finished;
 	GnomeCanvasItem *item;
 	GnomeCanvasItem *parent;
 	guint mask;
 
-	/* Choose where we send the event */
-
-	item = canvas->current_item;
-
-	if (canvas->focused_item
-	    && ((event->type == GDK_KEY_PRESS) || (event->type == GDK_KEY_RELEASE) || (event->type == GDK_FOCUS_CHANGE)))
-		item = canvas->focused_item;
-
-	if (canvas->grabbed_item)
-		item = canvas->grabbed_item;
-
 	/* Perform checks for grabbed items */
 
+	if (canvas->grabbed_item && !is_descendant (canvas->current_item, canvas->grabbed_item))
+		return FALSE;
+
 	if (canvas->grabbed_item) {
 		switch (event->type) {
 		case GDK_ENTER_NOTIFY:
@@ -223,14 +232,14 @@ emit_event (GnomeCanvas *canvas, GdkEvent *event)
 	 * offsets of the fields in the event structures.
 	 */
 
-	ev = gdk_event_copy (event);
+	ev = *event;
 
-	switch (ev->type) {
+	switch (ev.type) {
 	case GDK_ENTER_NOTIFY:
 	case GDK_LEAVE_NOTIFY:
 		gnome_canvas_window_to_world (canvas,
-					      ev->crossing.x, ev->crossing.y,
-					      &ev->crossing.x, &ev->crossing.y);
+					      ev.crossing.x, ev.crossing.y,
+					      &ev.crossing.x, &ev.crossing.y);
 		break;
 
 	case GDK_MOTION_NOTIFY:
@@ -239,14 +248,22 @@ emit_event (GnomeCanvas *canvas, GdkEvent *event)
 	case GDK_3BUTTON_PRESS:
 	case GDK_BUTTON_RELEASE:
 		gnome_canvas_window_to_world (canvas,
-					      ev->motion.x, ev->motion.y,
-					      &ev->motion.x, &ev->motion.y);
+					      ev.motion.x, ev.motion.y,
+					      &ev.motion.x, &ev.motion.y);
 		break;
 
 	default:
 		break;
 	}
 
+	/* Choose where we send the event */
+
+	item = canvas->current_item;
+
+	if (canvas->focused_item
+	    && ((event->type == GDK_KEY_PRESS) || (event->type == GDK_KEY_RELEASE) || (event->type == GDK_FOCUS_CHANGE)))
+		item = canvas->focused_item;
+
 	/* The event is propagated up the hierarchy (for if someone connected to
 	 * a group instead of a leaf event), and emission is stopped if a
 	 * handler returns TRUE, just like for GtkWidget events.
@@ -255,18 +272,24 @@ emit_event (GnomeCanvas *canvas, GdkEvent *event)
 	finished = FALSE;
 
 	while (item && !finished) {
-		g_object_ref (item);
+		gtk_object_ref (GTK_OBJECT (item));
 
-		g_signal_emit_by_name (item, "event", ev, &finished);
+		gtk_signal_emit_by_name (GTK_OBJECT (item), "event",
+					 &ev,
+					 &finished);
+
+#warning FIXME - needs thought
+#if 0
+		if (GTK_OBJECT_DESTROYED (item))
+			finished = TRUE;
+#endif
 
 		parent = item->parent;
-		g_object_unref (item);
+		gtk_object_unref (GTK_OBJECT (item));
 
 		item = parent;
 	}
 
-	gdk_event_free (ev);
-
 	return finished;
 }
 
@@ -344,7 +367,6 @@ pick_current_item (GnomeCanvas *canvas, GdkEvent *event)
 				       | GDK_BUTTON3_MASK
 				       | GDK_BUTTON4_MASK
 				       | GDK_BUTTON5_MASK);
-	d(g_print ("%s:%d: button_down = %s\n", __FUNCTION__, __LINE__, button_down ? "TRUE" : "FALSE"));
 	if (!button_down)
 		canvas->left_grabbed_item = FALSE;
 
@@ -483,12 +505,6 @@ e_canvas_button (GtkWidget *widget, GdkEventButton *event)
 
 	canvas = GNOME_CANVAS (widget);
 
-	d(g_print ("button %d, event type %d, grabbed=%p, current=%p\n",
-		   event->button,
-		   event->type,
-		   canvas->grabbed_item,
-		   canvas->current_item));
-
         /* dispatch normally regardless of the event's window if an item has
            has a pointer grab in effect */
 	if (!canvas->grabbed_item && event->window != canvas->layout.bin_window)
@@ -618,7 +634,10 @@ e_canvas_focus_in (GtkWidget *widget, GdkEventFocus *event)
 
 	GTK_WIDGET_SET_FLAGS (widget, GTK_HAS_FOCUS);
 
-	gtk_im_context_focus_in (ecanvas->im_context);
+#ifdef GAL_GDK_IM
+	if (ecanvas->ic)
+		gdk_im_begin (ecanvas->ic, canvas->layout.bin_window);
+#endif
 
 	if (canvas->focused_item) {
 		full_event.focus_change = *event;
@@ -641,7 +660,10 @@ e_canvas_focus_out (GtkWidget *widget, GdkEventFocus *event)
 
 	GTK_WIDGET_UNSET_FLAGS (widget, GTK_HAS_FOCUS);
 
-	gtk_im_context_focus_out (ecanvas->im_context);
+#ifdef GAL_GDK_IM
+	if (ecanvas->ic)
+		gdk_im_end ();
+#endif
 
 	if (canvas->focused_item) {
 		full_event.focus_change = *event;
@@ -651,43 +673,74 @@ e_canvas_focus_out (GtkWidget *widget, GdkEventFocus *event)
 	}
 }
 
-static void
-ec_style_set_recursive (GnomeCanvasItem *item, GtkStyle *previous_style)
-{
-	guint signal_id = g_signal_lookup ("style_set", G_OBJECT_TYPE (item));
-	if (signal_id >= 1) {
-		GSignalQuery query;
-		g_signal_query (signal_id, &query);
-		if (query.return_type == GTK_TYPE_NONE && query.n_params == 1 && query.param_types[0] == GTK_TYPE_STYLE) {
-			g_signal_emit (item, signal_id, 0, previous_style);
-		}
-	}
-
-	if (GNOME_IS_CANVAS_GROUP (item) ) {
-		GList *items = GNOME_CANVAS_GROUP (item)->item_list;
-		for (; items; items = items->next)
-			ec_style_set_recursive (items->data, previous_style);
-	}
-}
-
-static void
-e_canvas_style_set (GtkWidget *widget, GtkStyle *previous_style)
-{
-	ec_style_set_recursive (GNOME_CANVAS_ITEM (gnome_canvas_root (GNOME_CANVAS (widget))), previous_style);
-}
-
-
 static void
 e_canvas_realize (GtkWidget *widget)
 {
+	gint width, height;
+#ifdef GAL_GDK_IM
 	ECanvas *ecanvas = E_CANVAS (widget);
+#endif
 
 	if (GTK_WIDGET_CLASS (parent_class)->realize)
 		(* GTK_WIDGET_CLASS (parent_class)->realize) (widget);
 
 	gdk_window_set_back_pixmap (GTK_LAYOUT (widget)->bin_window, NULL, FALSE);
 
-	gtk_im_context_set_client_window (ecanvas->im_context, widget->window);
+#ifdef GAL_GDK_IM
+	if (gdk_im_ready () && (ecanvas->ic_attr = gdk_ic_attr_new ()) != NULL) {
+		GdkEventMask mask;
+		GdkICAttr *attr = ecanvas->ic_attr;
+		GdkICAttributesType attrmask = GDK_IC_ALL_REQ;
+		GdkIMStyle style;
+		GdkIMStyle supported_style = GDK_IM_PREEDIT_NONE |
+			GDK_IM_PREEDIT_NOTHING |
+			GDK_IM_PREEDIT_POSITION |
+			GDK_IM_STATUS_NONE |
+			GDK_IM_STATUS_NOTHING;
+
+		if(widget->style && widget->style->font->type != GDK_FONT_FONTSET)
+			supported_style &= ~GDK_IM_PREEDIT_POSITION;
+
+		attr->style = style = gdk_im_decide_style (supported_style);
+		attr->client_window = ecanvas->parent.layout.bin_window;
+
+		switch (style & GDK_IM_PREEDIT_MASK)
+			{
+			case GDK_IM_PREEDIT_POSITION:
+				if (widget->style && widget->style->font->type != GDK_FONT_FONTSET)
+					{
+						g_warning ("over-the-spot style requires fontset");
+						break;
+					}
+				
+				gdk_window_get_size (attr->client_window, &width, &height);
+				height = widget->style->font->ascent +
+					widget->style->font->descent;
+
+				attrmask |= GDK_IC_PREEDIT_POSITION_REQ;
+				attr->spot_location.x = 0;
+				attr->spot_location.y = height;
+				attr->preedit_area.x = 0;
+				attr->preedit_area.y = 0;
+				attr->preedit_area.width = width;
+				attr->preedit_area.height = height;
+				attr->preedit_fontset = widget->style->font;
+
+				break;
+			}
+
+		ecanvas->ic = gdk_ic_new (attr, attrmask);
+		if (ecanvas->ic != NULL) {
+			mask = gdk_window_get_events (attr->client_window);
+			mask |= gdk_ic_get_events (ecanvas->ic);
+			gdk_window_set_events (attr->client_window, mask);
+
+			if (GTK_WIDGET_HAS_FOCUS (widget))
+				gdk_im_begin (ecanvas->ic, attr->client_window);
+		} else
+			g_warning ("Can't create input context.");
+	}
+#endif
 }
 
 static void
@@ -700,8 +753,16 @@ e_canvas_unrealize (GtkWidget *widget)
 		ecanvas->idle_id = 0;
 	}
 
-	gtk_im_context_set_client_window (ecanvas->im_context, widget->window);
-
+#ifdef GAL_GDK_IM
+	if (ecanvas->ic) {
+		gdk_ic_destroy (ecanvas->ic);
+		ecanvas->ic = NULL;
+	}
+	if (ecanvas->ic_attr) {
+		gdk_ic_attr_destroy (ecanvas->ic_attr);
+		ecanvas->ic_attr = NULL;
+	}
+#endif
 	if (GTK_WIDGET_CLASS (parent_class)->unrealize)
 		(* GTK_WIDGET_CLASS (parent_class)->unrealize) (widget);
 }
@@ -724,9 +785,8 @@ e_canvas_item_invoke_reflow (GnomeCanvasItem *item, int flags)
 
 	if (item->object.flags & E_CANVAS_ITEM_NEEDS_REFLOW) {
 		ECanvasItemReflowFunc func;
-		func = (ECanvasItemReflowFunc)
-			g_object_get_data (G_OBJECT (item),
-					   "ECanvasItem::reflow_callback");
+		func = gtk_object_get_data (GTK_OBJECT (item),
+					    "ECanvasItem::reflow_callback");
 		if (func)
 			func (item, flags);
 	}
@@ -756,8 +816,8 @@ idle_handler (gpointer data)
 	/* Reset idle id */
 	canvas->idle_id = 0;
 
-	g_signal_emit (canvas,
-		       e_canvas_signals [REFLOW], 0);
+	gtk_signal_emit (GTK_OBJECT (canvas),
+			 e_canvas_signals [REFLOW]);
 
 	GDK_THREADS_LEAVE();
 
@@ -806,20 +866,20 @@ e_canvas_item_request_parent_reflow (GnomeCanvasItem *item)
 void
 e_canvas_item_set_reflow_callback (GnomeCanvasItem *item, ECanvasItemReflowFunc func)
 {
-	g_object_set_data(G_OBJECT(item), "ECanvasItem::reflow_callback", (gpointer) func);
+	gtk_object_set_data(GTK_OBJECT(item), "ECanvasItem::reflow_callback", (gpointer) func);
 }
 
 
 void
 e_canvas_item_set_selection_callback (GnomeCanvasItem *item, ECanvasItemSelectionFunc func)
 {
-	g_object_set_data(G_OBJECT(item), "ECanvasItem::selection_callback", (gpointer) func);
+	gtk_object_set_data(GTK_OBJECT(item), "ECanvasItem::selection_callback", (gpointer) func);
 }
 
 void
 e_canvas_item_set_selection_compare_callback (GnomeCanvasItem *item, ECanvasItemSelectionCompareFunc func)
 {
-	g_object_set_data(G_OBJECT(item), "ECanvasItem::selection_compare_callback", (gpointer) func);
+	gtk_object_set_data(GTK_OBJECT(item), "ECanvasItem::selection_compare_callback", (gpointer) func);
 }
 
 void
@@ -842,13 +902,12 @@ e_canvas_item_set_cursor (GnomeCanvasItem *item, gpointer id)
 	for (list = canvas->selection; list; list = g_list_next(list)) {
 		info = list->data;
 
-		func = (ECanvasItemSelectionFunc)g_object_get_data(G_OBJECT(info->item),
-								   "ECanvasItem::selection_callback");
+		func = gtk_object_get_data(GTK_OBJECT(info->item), "ECanvasItem::selection_callback");
 		if (func)
 			func(info->item, flags, info->id);
 		g_message ("ECANVAS: free info (2): item %p, id %p",
 			   info->item, info->id);
-		g_object_unref (info->item);
+		gtk_object_unref (GTK_OBJECT (info->item));
 		g_free(info);
 	}
 	g_list_free(canvas->selection);
@@ -859,13 +918,12 @@ e_canvas_item_set_cursor (GnomeCanvasItem *item, gpointer id)
 
 	info = g_new(ECanvasSelectionInfo, 1);
 	info->item = item;
-	g_object_ref (info->item);
+	gtk_object_ref (GTK_OBJECT (info->item));
 	info->id = id;
 	g_message ("ECANVAS: new info item %p, id %p", item, id);
 
 	flags = E_CANVAS_ITEM_SELECTION_SELECT | E_CANVAS_ITEM_SELECTION_CURSOR;
-	func = (ECanvasItemSelectionFunc)g_object_get_data(G_OBJECT(item),
-							   "ECanvasItem::selection_callback");
+	func = gtk_object_get_data(GTK_OBJECT(item), "ECanvasItem::selection_callback");
 	if (func)
 		func(item, flags, id);
 
@@ -896,8 +954,7 @@ e_canvas_item_add_selection (GnomeCanvasItem *item, gpointer id)
 	canvas = E_CANVAS(item->canvas);
 
 	if (canvas->cursor) {
-		func = (ECanvasItemSelectionFunc)g_object_get_data(G_OBJECT(canvas->cursor->item),
-								   "ECanvasItem::selection_callback");
+		func = gtk_object_get_data(GTK_OBJECT(canvas->cursor->item), "ECanvasItem::selection_callback");
 		if (func)
 			func(canvas->cursor->item, flags, canvas->cursor->id);
 	}
@@ -912,13 +969,11 @@ e_canvas_item_add_selection (GnomeCanvasItem *item, gpointer id)
 
 		if (search->item == item) {
 			ECanvasItemSelectionCompareFunc compare_func;
-			compare_func = (ECanvasItemSelectionCompareFunc)g_object_get_data(G_OBJECT(search->item),
-											  "ECanvasItem::selection_compare_callback");
+			compare_func = gtk_object_get_data(GTK_OBJECT(search->item), "ECanvasItem::selection_compare_callback");
 
 			if (compare_func(search->item, search->id, id, 0) == 0) {
 				canvas->cursor = search;
-				func = (ECanvasItemSelectionFunc)g_object_get_data(G_OBJECT(item),
-										   "ECanvasItem::selection_callback");
+				func = gtk_object_get_data(GTK_OBJECT(item), "ECanvasItem::selection_callback");
 				if (func)
 					func(item, flags, search->id);
 				return;
@@ -928,12 +983,11 @@ e_canvas_item_add_selection (GnomeCanvasItem *item, gpointer id)
 
 	info = g_new(ECanvasSelectionInfo, 1);
 	info->item = item;
-	g_object_ref (info->item);
+	gtk_object_ref (GTK_OBJECT (info->item));
 	info->id = id;
 	g_message ("ECANVAS: new info (2): item %p, id %p", item, id);
 
-	func = (ECanvasItemSelectionFunc)g_object_get_data(G_OBJECT(item),
-							   "ECanvasItem::selection_callback");
+	func = gtk_object_get_data(GTK_OBJECT(item), "ECanvasItem::selection_callback");
 	if (func)
 		func(item, flags, id);
 
@@ -962,13 +1016,11 @@ e_canvas_item_remove_selection (GnomeCanvasItem *item, gpointer id)
 
 		if (info->item == item) {
 			ECanvasItemSelectionCompareFunc compare_func;
-			compare_func = (ECanvasItemSelectionCompareFunc)g_object_get_data(G_OBJECT(info->item),
-											  "ECanvasItem::selection_compare_callback");
+			compare_func = gtk_object_get_data(GTK_OBJECT(info->item), "ECanvasItem::selection_compare_callback");
 
 			if (compare_func(info->item, info->id, id, 0) == 0) {
 				ECanvasItemSelectionFunc func;
-				func = (ECanvasItemSelectionFunc) g_object_get_data(G_OBJECT(info->item),
-										    "ECanvasItem::selection_callback");
+				func = gtk_object_get_data(GTK_OBJECT(info->item), "ECanvasItem::selection_callback");
 				if (func)
 					func(info->item, flags, info->id);
 				canvas->selection = g_list_remove_link(canvas->selection, list);
@@ -978,7 +1030,7 @@ e_canvas_item_remove_selection (GnomeCanvasItem *item, gpointer id)
 
 				g_message ("ECANVAS: removing info: item %p, info %p",
 					   info->item, info->id);
-				g_object_unref (info->item);
+				gtk_object_unref (GTK_OBJECT (info->item));
 				g_free(info);
 				g_list_free_1(list);
 				break;
@@ -998,10 +1050,10 @@ void e_canvas_popup_tooltip (ECanvas *canvas, GtkWidget *widget, int x, int y)
 		canvas->toplevel = gtk_widget_get_toplevel (GTK_WIDGET(canvas));
 		if (canvas->toplevel) {
 			gtk_widget_add_events(canvas->toplevel, GDK_VISIBILITY_NOTIFY_MASK);
-			g_object_ref (canvas->toplevel);
+			gtk_object_ref(GTK_OBJECT(canvas->toplevel));
 			canvas->visibility_notify_id =
-				g_signal_connect (canvas->toplevel, "visibility_notify_event",
-						  G_CALLBACK (e_canvas_visibility), canvas);
+				gtk_signal_connect (GTK_OBJECT (canvas->toplevel), "visibility_notify_event",
+						    GTK_SIGNAL_FUNC (e_canvas_visibility), canvas);
 		}
 	}
 	gtk_widget_set_uposition (widget, x, y);
@@ -1015,77 +1067,3 @@ void e_canvas_hide_tooltip  (ECanvas *canvas)
 		canvas->tooltip_window = NULL;
 	}
 }
-
-
-static gboolean
-grab_cancelled_check (gpointer data)
-{
-	ECanvas *canvas = data;
-
-	if (GNOME_CANVAS (canvas)->grabbed_item == NULL) {
-		canvas->grab_cancelled_cb = NULL;
-		canvas->grab_cancelled_check_id = 0;
-		canvas->grab_cancelled_time = 0;
-		canvas->grab_cancelled_data = NULL;
-		return FALSE;
-	}
-
-	if (gtk_grab_get_current ()) {
-		gnome_canvas_item_ungrab(GNOME_CANVAS (canvas)->grabbed_item, canvas->grab_cancelled_time);
-		if (canvas->grab_cancelled_cb) {
-			canvas->grab_cancelled_cb (canvas,
-						   GNOME_CANVAS (canvas)->grabbed_item,
-						   canvas->grab_cancelled_data);
-		}
-		canvas->grab_cancelled_cb = NULL;
-		canvas->grab_cancelled_check_id = 0;
-		canvas->grab_cancelled_time = 0;
-		canvas->grab_cancelled_data = NULL;
-		return FALSE;
-	}
-	return TRUE;
-}
-
-int
-e_canvas_item_grab (ECanvas *canvas,
-		    GnomeCanvasItem *item,
-		    guint event_mask,
-		    GdkCursor *cursor,
-		    guint32 etime,
-		    ECanvasItemGrabCancelled cancelled_cb,
-		    gpointer cancelled_data)
-{
-	if (gtk_grab_get_current ()) {
-		return AlreadyGrabbed;
-	} else {
-		int ret_val = gnome_canvas_item_grab (item, event_mask, cursor, etime);
-		if (ret_val == GrabSuccess) {
-			canvas->grab_cancelled_cb = cancelled_cb;
-			canvas->grab_cancelled_check_id =
-				g_timeout_add_full (G_PRIORITY_LOW,
-						    100,
-						    grab_cancelled_check,
-						    canvas,
-						    NULL);
-			canvas->grab_cancelled_time = etime;
-			canvas->grab_cancelled_data = cancelled_data;
-		}
-
-		return ret_val;
-	}
-}
-
-void
-e_canvas_item_ungrab (ECanvas *canvas,
-		      GnomeCanvasItem *item,
-		      guint32 etime)
-{
-	if (canvas->grab_cancelled_check_id) {
-		g_source_remove (canvas->grab_cancelled_check_id);
-		canvas->grab_cancelled_cb = NULL;
-		canvas->grab_cancelled_check_id = 0;
-		canvas->grab_cancelled_time = 0;
-		canvas->grab_cancelled_data = NULL;
-		gnome_canvas_item_ungrab (item, etime);
-	}
-}
